==> cr12g-panhuo-api-3.0.0-20210510.094220-8-sources.jar: com/ejianc/business/panhuo/vo/AddressVO.java <==
package com.ejianc.business.panhuo.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 地址管理
 * 
 * @author generator
 * 
 */
public class AddressVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String projectName; // 项目名称
    private Long projectId; // 项目主键
    private Long orgId; // 组织主键
    private String orgName; // 组织名称
    private Long userId; // 用户主键
    private Double lon; // 经度
    private Double lat; // 纬度
    private String firstLocation; // 所在地一级区域省
    private String secondLocation; // 所在地二级区域市
    private String thirdLocation; // 所在地三级区域区/县
    private String fourthLocation; // 所在地四级区域乡/镇
    private String location; // 所在地末级区域街道/村/社区
    private String projectAddress; // 项目地址区域
    private String detailAddress; // 具体地址
    private String address; // 完整地址
    private String phone; // 联系方式
    private String name; // 联系人
    private Integer isquote; // 0=是，1=不是
    private Integer belongType; // 类型 0=项目，1=公司
    

    /**
     * 项目名称
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    /**
     * 项目主键
     */
    public Long getProjectId() {
        return projectId;
    }

    /**
     * 项目主键
     */
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 组织主键
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织主键
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 用户主键
     */
    public Long getUserId() {
        return userId;
    }

    /**
     * 用户主键
     */
    public void setUserId(Long userId) {
        this.userId = userId;
    }
    /**
     * 经度
     */
    public Double getLon() {
        return lon;
    }

    /**
     * 经度
     */
    public void setLon(Double lon) {
        this.lon = lon;
    }
    /**
     * 纬度
     */
    public Double getLat() {
        return lat;
    }

    /**
     * 纬度
     */
    public void setLat(Double lat) {
        this.lat = lat;
    }
    /**
     * 所在地一级区域省
     */
    public String getFirstLocation() {
        return firstLocation;
    }

    /**
     * 所在地一级区域省
     */
    public void setFirstLocation(String firstLocation) {
        this.firstLocation = firstLocation;
    }
    /**
     * 所在地二级区域市
     */
    public String getSecondLocation() {
        return secondLocation;
    }

    /**
     * 所在地二级区域市
     */
    public void setSecondLocation(String secondLocation) {
        this.secondLocation = secondLocation;
    }
    /**
     * 所在地三级区域区/县
     */
    public String getThirdLocation() {
        return thirdLocation;
    }

    /**
     * 所在地三级区域区/县
     */
    public void setThirdLocation(String thirdLocation) {
        this.thirdLocation = thirdLocation;
    }
    /**
     * 所在地四级区域乡/镇
     */
    public String getFourthLocation() {
        return fourthLocation;
    }

    /**
     * 所在地四级区域乡/镇
     */
    public void setFourthLocation(String fourthLocation) {
        this.fourthLocation = fourthLocation;
    }
    /**
     * 所在地末级区域街道/村/社区
     */
    public String getLocation() {
        return location;
    }

    /**
     * 所在地末级区域街道/村/社区
     */
    public void setLocation(String location) {
        this.location = location;
    }
    /**
     * 项目地址区域
     */
    public String getProjectAddress() {
        return projectAddress;
    }

    /**
     * 项目地址区域
     */
    public void setProjectAddress(String projectAddress) {
        this.projectAddress = projectAddress;
    }
    /**
     * 具体地址
     */
    public String getDetailAddress() {
        return detailAddress;
    }

    /**
     * 具体地址
     */
    public void setDetailAddress(String detailAddress) {
        this.detailAddress = detailAddress;
    }
    /**
     * 完整地址
     */
    public String getAddress() {
        return address;
    }

    /**
     * 完整地址
     */
    public void setAddress(String address) {
        this.address = address;
    }
    /**
     * 联系方式
     */
    public String getPhone() {
        return phone;
    }

    /**
     * 联系方式
     */
    public void setPhone(String phone) {
        this.phone = phone;
    }
    /**
     * 联系人
     */
    public String getName() {
        return name;
    }

    /**
     * 联系人
     */
    public void setName(String name) {
        this.name = name;
    }
    /**
     * 0=是，1=不是
     */
    public Integer getIsquote() {
        return isquote;
    }

    /**
     * 0=是，1=不是
     */
    public void setIsquote(Integer isquote) {
        this.isquote = isquote;
    }
    /**
     * 类型 0=项目，1=公司
     */
    public Integer getBelongType() {
        return belongType;
    }

    /**
     * 类型 0=项目，1=公司
     */
    public void setBelongType(Integer belongType) {
        this.belongType = belongType;
    }
    
}

==> cr12g-panhuo-api-3.0.0-20210511.120555-21-sources.jar: com/ejianc/business/panhuo/vo/AddressVO.java <==
package com.ejianc.business.panhuo.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 地址管理
 * 
 * @author generator
 * 
 */
public class AddressVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String projectName; // 项目名称
    private Long projectId; // 项目主键
    private Long orgId; // 组织主键
    private String orgName; // 组织名称
    private Long userId; // 用户主键
    private Double lon; // 经度
    private Double lat; // 纬度
    private String firstLocation; // 所在地一级区域省
    private String secondLocation; // 所在地二级区域市
    private String thirdLocation; // 所在地三级区域区/县
    private String fourthLocation; // 所在地四级区域乡/镇
    private String location; // 所在地末级区域街道/村/社区
    private String projectAddress; // 项目地址区域
    private String detailAddress; // 具体地址
    private String address; // 完整地址
    private String phone; // 联系方式
    private String name; // 联系人
    private Integer isquote; // 0=是，1=不是
    private Integer belongType; // 类型 0=项目，1=公司
    

    /**
     * 项目名称
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    /**
     * 项目主键
     */
    @ReferSerialTransfer(referCode="market-project")
    public Long getProjectId() {
        return projectId;
    }

    /**
     * 项目主键
     */
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 组织主键
     */
    @ReferSerialTransfer(referCode="idm-org")
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织主键
     */
    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 用户主键
     */
    public Long getUserId() {
        return userId;
    }

    /**
     * 用户主键
     */
    public void setUserId(Long userId) {
        this.userId = userId;
    }
    /**
     * 经度
     */
    public Double getLon() {
        return lon;
    }

    /**
     * 经度
     */
    public void setLon(Double lon) {
        this.lon = lon;
    }
    /**
     * 纬度
     */
    public Double getLat() {
        return lat;
    }

    /**
     * 纬度
     */
    public void setLat(Double lat) {
        this.lat = lat;
    }
    /**
     * 所在地一级区域省
     */
    public String getFirstLocation() {
        return firstLocation;
    }

    /**
     * 所在地一级区域省
     */
    public void setFirstLocation(String firstLocation) {
        this.firstLocation = firstLocation;
    }
    /**
     * 所在地二级区域市
     */
    public String getSecondLocation() {
        return secondLocation;
    }

    /**
     * 所在地二级区域市
     */
    public void setSecondLocation(String secondLocation) {
        this.secondLocation = secondLocation;
    }
    /**
     * 所在地三级区域区/县
     */
    public String getThirdLocation() {
        return thirdLocation;
    }

    /**
     * 所在地三级区域区/县
     */
    public void setThirdLocation(String thirdLocation) {
        this.thirdLocation = thirdLocation;
    }
    /**
     * 所在地四级区域乡/镇
     */
    public String getFourthLocation() {
        return fourthLocation;
    }

    /**
     * 所在地四级区域乡/镇
     */
    public void setFourthLocation(String fourthLocation) {
        this.fourthLocation = fourthLocation;
    }
    /**
     * 所在地末级区域街道/村/社区
     */
    public String getLocation() {
        return location;
    }

    /**
     * 所在地末级区域街道/村/社区
     */
    public void setLocation(String location) {
        this.location = location;
    }
    /**
     * 项目地址区域
     */
    public String getProjectAddress() {
        return projectAddress;
    }

    /**
     * 项目地址区域
     */
    public void setProjectAddress(String projectAddress) {
        this.projectAddress = projectAddress;
    }
    /**
     * 具体地址
     */
    public String getDetailAddress() {
        return detailAddress;
    }

    /**
     * 具体地址
     */
    public void setDetailAddress(String detailAddress) {
        this.detailAddress = detailAddress;
    }
    /**
     * 完整地址
     */
    public String getAddress() {
        return address;
    }

    /**
     * 完整地址
     */
    public void setAddress(String address) {
        this.address = address;
    }
    /**
     * 联系方式
     */
    public String getPhone() {
        return phone;
    }

    /**
     * 联系方式
     */
    public void setPhone(String phone) {
        this.phone = phone;
    }
    /**
     * 联系人
     */
    public String getName() {
        return name;
    }

    /**
     * 联系人
     */
    public void setName(String name) {
        this.name = name;
    }
    /**
     * 0=是，1=不是
     */
    public Integer getIsquote() {
        return isquote;
    }

    /**
     * 0=是，1=不是
     */
    public void setIsquote(Integer isquote) {
        this.isquote = isquote;
    }
    /**
     * 类型 0=项目，1=公司
     */
    public Integer getBelongType() {
        return belongType;
    }

    /**
     * 类型 0=项目，1=公司
     */
    public void setBelongType(Integer belongType) {
        this.belongType = belongType;
    }
    
}
